@@ -595,9 +595,9 @@ expect_true(
     length(BiocCheck:::.findSignalerInSignaler(rfile, .SIGNALERS_TXT)) == 4L
 )
 
-# installAndLoad ----------------------------------------------------------
+# .tryInstallwLoad --------------------------------------------------------
 .bioctest <- create_test_package()
-temppkg <- BiocCheck:::installAndLoad(.bioctest)
+temppkg <- BiocCheck:::.tryInstallwLoad(.bioctest)
 liblocation <- file.path(temppkg, "lib")
 expect_true(dir.exists(liblocation))
 expect_true(
@@ -708,6 +708,37 @@ msg <- BiocCheck:::checkEqInAssignment(
 expect_equivalent(length(msg), 3)
 .BiocCheck$zero()
 
+
+# checkVignetteDir for Rhtml ----------------------------------------------
+temp_dir <- tempfile()
+.bioctest <- create_test_package(
+    test_dir = temp_dir,
+    description = list(
+        VignetteBuilder="knitr", Suggests="knitr,rmarkdown"
+    ),
+    extraActions = function(pkgpath) {
+        vigdir <- file.path(pkgpath, "vignettes")
+        if (!dir.exists(vigdir))
+            dir.create(vigdir, recursive = TRUE)
+        file.copy(
+            system.file(
+                "testfiles", "test.Rhtml",
+                package = "BiocCheck", mustWork = TRUE
+            ),
+            file.path(vigdir, "test.Rhtml")
+        )
+    }
+)
+BiocCheck:::checkVignetteDir(.bioctest)
+expect_equivalent(
+    length(.BiocCheck$get("note")[["checkChunkLabels"]]), 3
+)
+checkCounter(
+    "Rhtml vignette missing chunk labels didn't cause note!",
+    "note"
+)
+.BiocCheck$zero()
+
 # checkVigInstalls --------------------------------------------------------
 .bioctest <- read_test_package("testpkg0")
 BiocCheck:::checkVigInstalls(.bioctest)
@@ -891,7 +922,7 @@ expect_true(
 
 # checkExportsAreDocumented ------------------------------------------------
 .bioctest <- read_test_package("testpkg0")
-instdir <- BiocCheck:::installAndLoad(.bioctest)
+instdir <- BiocCheck:::.tryInstallwLoad(.bioctest)
 res <- BiocCheck:::checkExportsAreDocumented(
     .bioctest, lib.loc = file.path(instdir, "lib")
 )
@@ -1301,7 +1332,7 @@ expect_true(
 # checkUsageOfDont ---------------------------------------------------------
 ## testpkg0 should trigger this note for 2 out of 3 man pages
 .bioctest <- read_test_package("testpkg0")
-BiocCheck:::installAndLoad(.bioctest)
+BiocCheck:::.tryInstallwLoad(.bioctest)
 notemsg <- capture.output(
     BiocCheck:::checkUsageOfDont(.bioctest), type = "message"
 )
@@ -1313,7 +1344,7 @@ expect_true( any(grepl("67%", notemsg)) )
 ## testpkg1 contains a man page with keyword 'internal'
 ## this shouldn't trigger the note
 .bioctest <- read_test_package("testpkg1")
-BiocCheck:::installAndLoad(.bioctest)
+BiocCheck:::.tryInstallwLoad(.bioctest)
 BiocCheck:::checkUsageOfDont(.bioctest)
 expect_equivalent(0, .BiocCheck$getNum("note"))
 .BiocCheck$zero()
